@@ -19,7 +19,7 @@
 #' @inheritParams active_snw_search
 #' @inheritParams enrichment_analyses
 #' @param iterations number of iterations for active subnetwork search and
-#'  enrichment analyses (Default = 10. Gets set to 1 for Genetic Algorithm)
+#'  enrichment analyses (Default = 1)
 #' @param n_processes optional argument for specifying the number of processes
 #'  used by foreach. If not specified, the function determines this
 #'  automatically (Default == NULL. Gets set to 1 for Genetic Algorithm)
@@ -37,6 +37,7 @@
 #'   \item{Term_Description}{Description of the enriched term}
 #'   \item{Fold_Enrichment}{Fold enrichment value for the enriched term (Calculated using ONLY the input genes)}
 #'   \item{occurrence}{the number of iterations that the given term was found to enriched over all iterations}
+#'   \item{support}{the median support (proportion of active subnetworks leading to enrichment within an iteration) over all iterations}
 #'   \item{lowest_p}{the lowest adjusted-p value of the given term over all iterations}
 #'   \item{highest_p}{the highest adjusted-p value of the given term over all iterations}
 #'   \item{non_Signif_Snw_Genes (OPTIONAL)}{the non-significant active subnetwork genes, comma-separated}
@@ -101,8 +102,8 @@ run_pathfindR <- function(input,
                           gaCrossover = 1, gaMut = 0,
                           grMaxDepth = 1, grSearchDepth = 1,
                           grOverlap = 0.5, grSubNum = 1000,
-                          iterations = 10, n_processes = NULL,
-                          score_quan_thr = 0.80, sig_gene_thr = 0.02,
+                          iterations = 1, n_processes = NULL,
+                          score_quan_thr = 0.8, sig_gene_thr = 0.02,
                           plot_enrichment_chart = TRUE,
                           output_dir = "pathfindR_Results",
                           list_active_snw_genes = FALSE,
@@ -117,7 +118,8 @@ run_pathfindR <- function(input,
 
   ## If search_method is GA, set iterations as 1
   if (search_method == "GA") {
-    warning("`iterations` is set to 1 because `search_method = \"GA\"`")
+    warning("`iterations` is set to 1 because `search_method = \"GA\"`",
+            call. = FALSE)
     iterations <- 1
   }
 
@@ -128,19 +130,14 @@ run_pathfindR <- function(input,
     if (n_processes < 1) {
       stop("`n_processes` should be > 1")
     }
-
-    ## If iterations < n_processes, set n_processes to iterations
-    if (iterations < n_processes) {
-      warning("`n_processes` is set to `iterations` because `iterations` < `n_processes`")
-      n_processes <- iterations
-    }
   }
 
   # calculate the number of processes, if necessary
   if (is.null(n_processes))
     n_processes <- parallel::detectCores() - 1
 
-  if (iterations < n_processes) {
+  ## If iterations < n_processes, set n_processes to iterations
+  if (iterations < n_processes & iterations != 1) {
     message("`n_processes` is set to `iterations` because `iterations` < `n_processes`")
     n_processes <- iterations
   }
@@ -166,7 +163,7 @@ run_pathfindR <- function(input,
     stop("`iterations` should be a positive integer")
   }
   if (iterations < 1) {
-    stop("`iterations` should be > 1")
+    stop("`iterations` should be >= 1")
   }
 
   ############ Initial Steps
@@ -231,32 +228,19 @@ run_pathfindR <- function(input,
   ############ Active Subnetwork Search and Enrichment
   ## Prep for parallel run
   message("## Performing Active Subnetwork Search and Enrichment")
-  # Initiate the clusters
-  cl <- parallel::makeCluster(n_processes, setup_strategy = "sequential")
-  doParallel::registerDoParallel(cl)
 
-  dirs <- c()
-  for (i in base::seq_len(iterations)) {
-    dir_i <- paste0("active_snw_searches/Iteration_", i)
-    dir.create(dir_i, recursive = TRUE)
-    dirs <- c(dirs, dir_i)
-  }
-
-
-  `%dopar%` <- foreach::`%dopar%`
-  combined_res <- foreach::foreach(i = 1:iterations, .combine = rbind) %dopar% {
+  if (iterations == 1) {
 
     ## Active Subnetwork Search
     snws <- pathfindR::active_snw_search(input_for_search = input_processed,
                                          pin_name_path = pin_path,
-                                         snws_file = paste0("active_snws_", i),
-                                         dir_for_parallel_run = dirs[i],
+                                         snws_file = "active_snws",
                                          score_quan_thr = score_quan_thr,
                                          sig_gene_thr = sig_gene_thr,
                                          search_method = search_method,
                                          silent_option = silent_option,
                                          use_all_positives = use_all_positives,
-                                         geneInitProbs = geneInitProbs[i],
+                                         geneInitProbs = 0.1,
                                          saTemp0 = saTemp0, saTemp1 = saTemp1, saIter = saIter,
                                          gaPop = gaPop, gaIter = gaIter,
                                          gaThread = gaThread,
@@ -272,15 +256,59 @@ run_pathfindR <- function(input,
                                                      adj_method = adj_method,
                                                      enrichment_threshold = enrichment_threshold,
                                                      list_active_snw_genes = list_active_snw_genes)
+    combined_res <- enrichment_res
+  } else {
+    # Initiate the clusters
+    cl <- parallel::makeCluster(n_processes, setup_strategy = "sequential")
+    doParallel::registerDoParallel(cl)
 
-    enrichment_res
+    dirs <- c()
+    for (i in base::seq_len(iterations)) {
+      dir_i <- file.path("active_snw_searches", paste0("Iteration_", i))
+      dir.create(dir_i, recursive = TRUE)
+      dirs <- c(dirs, dir_i)
+    }
+
+    `%dopar%` <- foreach::`%dopar%`
+    combined_res <- foreach::foreach(i = 1:iterations, .combine = rbind) %dopar% {
+
+      ## Active Subnetwork Search
+      snws <- pathfindR::active_snw_search(input_for_search = input_processed,
+                                           pin_name_path = pin_path,
+                                           snws_file = paste0("active_snws_", i),
+                                           dir_for_parallel_run = dirs[i],
+                                           score_quan_thr = score_quan_thr,
+                                           sig_gene_thr = sig_gene_thr,
+                                           search_method = search_method,
+                                           silent_option = silent_option,
+                                           use_all_positives = use_all_positives,
+                                           geneInitProbs = geneInitProbs[i],
+                                           saTemp0 = saTemp0, saTemp1 = saTemp1, saIter = saIter,
+                                           gaPop = gaPop, gaIter = gaIter,
+                                           gaThread = gaThread,
+                                           gaCrossover = gaCrossover, gaMut = gaMut,
+                                           grMaxDepth = grMaxDepth, grSearchDepth = grSearchDepth,
+                                           grOverlap = grOverlap, grSubNum = grSubNum)
+
+      enrichment_res <- pathfindR::enrichment_analyses(snws = snws,
+                                                       sig_genes_vec = input_processed$GENE,
+                                                       pin_name_path = pin_path,
+                                                       genes_by_term = genes_by_term,
+                                                       term_descriptions = term_descriptions,
+                                                       adj_method = adj_method,
+                                                       enrichment_threshold = enrichment_threshold,
+                                                       list_active_snw_genes = list_active_snw_genes)
+
+      enrichment_res
+    }
+    parallel::stopCluster(cl)
   }
-  parallel::stopCluster(cl)
+
   setwd(output_dir)
 
   ## In case no enrichment was found
   if (is.null(combined_res)) {
-    warning("Did not find any enriched terms!")
+    warning("Did not find any enriched terms!", call. = FALSE)
     return(data.frame())
   }
 
@@ -670,7 +698,7 @@ input_processing <- function(input, p_val_threshold = 0.05,
 
   ## Turn GENE into character
   if (is.factor(input$GENE)) {
-    warning("The gene column was turned into character from factor.")
+    warning("The gene column was turned into character from factor.", call. = FALSE)
     input$GENE <- as.character(input$GENE)
   }
 
@@ -685,7 +713,7 @@ input_processing <- function(input, p_val_threshold = 0.05,
 
   ## Choose lowest p for each gene
   if (anyDuplicated(input$GENE)) {
-    warning("Duplicated genes found! The lowest p value for each gene was selected")
+    warning("Duplicated genes found! The lowest p value for each gene was selected", call. = FALSE)
 
     input <- input[order(input$P_VALUE, decreasing = FALSE), ]
     input <- input[!duplicated(input$GENE), ]
